@@ -14,7 +14,7 @@
 
 """Mock module."""
 
-import httpx, json, jwt, respx, secrets, time
+import httpx, flask, json, jwt, respx, secrets, time
 
 from cryptography.hazmat.primitives.asymmetric import rsa
 from jwt.algorithms import RSAAlgorithm
@@ -28,8 +28,9 @@ from iam_python_sdk.config import (
     REVOCATION_LIST_PATH,
     VERIFY_PATH,
 )
+from iam_python_sdk.flask import token_required, cors_options
 
-IAM_BASE_URL = "https://api.mock/iam"
+iam_base_url = "https://api.mock/iam"
 
 rsa_algorithm = RSAAlgorithm(hash_alg="RS256")
 rsa_private_key = rsa.generate_private_key(65537, 2048)
@@ -145,25 +146,25 @@ iam_mock = respx.mock(assert_all_called=False)
 
 
 # Client token grant mock api
-@iam_mock.post(url=IAM_BASE_URL + GRANT_PATH)
+@iam_mock.post(url=iam_base_url + GRANT_PATH)
 def get_token(request):
     return httpx.Response(200, json=client_token)
 
 
 # Get JWKS mock api
-@iam_mock.get(url=IAM_BASE_URL + JWKS_PATH)
+@iam_mock.get(url=iam_base_url + JWKS_PATH)
 def get_jwks(request):
     return httpx.Response(200, json=jwks)
 
 
 # Get revocation list mock api
-@iam_mock.get(url=IAM_BASE_URL + REVOCATION_LIST_PATH)
+@iam_mock.get(url=iam_base_url + REVOCATION_LIST_PATH)
 def get_revocation_list(request):
     return httpx.Response(200, json=revocation_list)
 
 
 # Validate access token mock api
-@iam_mock.post(url=IAM_BASE_URL + VERIFY_PATH)
+@iam_mock.post(url=iam_base_url + VERIFY_PATH)
 def verify_token(request):
     request_data = parse.parse_qs(request.content.decode("ascii"))
     access_token = request_data.get("token")
@@ -173,14 +174,42 @@ def verify_token(request):
 
 
 # Get client information mock api
-@iam_mock.get(url=IAM_BASE_URL + CLIENT_INFORMATION_PATH % (namespace, client_id))
+@iam_mock.get(url=iam_base_url + CLIENT_INFORMATION_PATH % (namespace, client_id))
 def get_client_info(request):
     return httpx.Response(200, json=client_info)
 
 
 # Get role permission mock api
-@iam_mock.get(url__regex=IAM_BASE_URL + GET_ROLE_PATH + "/" + r"(?P<role>\w+)")
+@iam_mock.get(url__regex=iam_base_url + GET_ROLE_PATH + "/" + r"(?P<role>\w+)")
 def role_api(request, role):
     if role != role_id:
         return httpx.Response(404)
     return httpx.Response(200, json=role_data)
+
+
+# Flask mock
+flask_mock = flask.Blueprint("flask_mock", __name__)
+
+
+@flask_mock.route('/')
+def unprotected():
+    return flask.jsonify({'status': 'unprotected'})
+
+
+@flask_mock.route('/protected')
+@token_required({"resource": "ADMIN:NAMESPACE:{namespace}:CLIENT", "action": 2}, {"{namespace}": "sdktest"}, False)
+def protected():
+    return flask.jsonify({'status': 'protected'})
+
+
+@flask_mock.route('/protected_with_csrf')
+@token_required({"resource": "ADMIN:NAMESPACE:{namespace}:CLIENT", "action": 2}, {"{namespace}": "sdktest"})
+def protected_with_csrf():
+    return flask.jsonify({'status': 'protected'})
+
+
+@flask_mock.route('/protected_with_cors', methods=["POST"])
+@token_required({"resource": "ADMIN:NAMESPACE:{namespace}:CLIENT", "action": 2}, {"{namespace}": "sdktest"})
+@cors_options({"Access-Control-Allow-Headers": ["Device-Id", "Device-Os", "Device-Type"]})
+def protected_with_cors():
+    return flask.jsonify({'status': 'protected'})
